bayespy.inference.vmp.nodes.categorical.CategoricalDistribution.compute_mask_to_parent
======================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.categorical

.. automethod:: CategoricalDistribution.compute_mask_to_parent